:github_url: https://github.com/stephane-caron/aiorate/tree/master/doc/src/index.rst

.. title:: Table of Contents

######
aiorate
#######

Loop frequency regulation for `asyncio <https://docs.python.org/3/library/asyncio.html>`_, with an API similar to `rospy.Rate <https://wiki.ros.org/rospy/Overview/Time#Sleeping_and_Rates>`_.

.. **Release 0.1 -- February 28, 2022**

.. toctree::
    :maxdepth: 1

    installation.rst

You can also download this documentation as a `PDF document <aiorate.pdf>`_.
